# -*- coding: utf-8 -*-
"""
sh_stock.py
上海证券交易所
"""
import json
import re
import time

from stock_open_api.api.sse import sh_stock_config
from stock_open_api.log import logger
from stock_open_api.utils import request_util


def get_company_info(stock_code):
    """
    股票概况 / 公司信息 / 公司概况

    页面地址
        eg: http://www.sse.com.cn/assortment/stock/list/info/company/index.shtml?COMPANY_CODE=688001

    :param stock_code: eg 688001

    :return:
    {
      "公司代码": "688001",
      "上市日-A": "",
      "代码-A": "688001",
      "简称-A": "华兴源创",
      "代码-B": "-",
      "上市日-B": "",
      "可转债简称": "华兴转债",
      "可转债代码": "",
      "可转债转股简称": "华兴转债",
      "可转债转股代码": "118003",
      "公司简称-中": "华兴源创",
      "公司简称-英": "HYC",
      "公司全称-中": "苏州华兴源创科技股份有限公司",
      "公司全称-英": "Suzhou HYC Technology CO., LTD",
      "扩位证券简称": "苏州华兴源创科技",
      "上市时是否盈利": "1",
      "是否具有表决权差异安排": "0",
      "注册地址": "苏州工业园区青丘巷8号",
      "通讯地址": "苏州工业园区青丘巷8号",
      "邮编": "215000",
      "法定代表人": "陈文源",
      "董事会秘书姓名": "",
      "E-mail": "dongmiban@hyc.cn",
      "联系电话": "",
      "网址": "http://www.hyc.cn",
      "CSRC行业": "高端装备",
      "SSE行业": "工业",
      "所属省/直辖市": "江苏",
      "状态-A": "上市",
      "状态-B": "-",
      "是否上证180样本股": "-",
      "是否境外上市": "-",
      "境外上市地": "-"
    }

    """
    url = "http://query.sse.com.cn/commonQuery.do"
    detail_url = f'http://www.sse.com.cn/assortment/stock/list/info/company/index.shtml?COMPANY_CODE={stock_code}'
    # print()

    logger.debug('Referer: %s', detail_url)

    params = {
        'jsonCallBack': 'jsonpCallback22015',
        'isPagination': 'false',
        'sqlId': 'COMMON_SSE_ZQPZ_GP_GPLB_C',
        'productid': stock_code,
        '_': int(time.time() * 1000),
    }

    headers = {
        'Accept': '*/*',
        'Accept-Encoding': 'gzip, deflate',
        'Accept-Language': 'zh-CN,zh;q=0.9,en-US;q=0.8,en;q=0.7',
        'Cache-Control': 'no-cache',
        'Connection': 'keep-alive',
        'Pragma': 'no-cache',
        'Referer': detail_url,
        'User-Agent': 'Mozilla/5.0 (Macintosh; Intel Mac OS X 10_14_4) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/84.0.4147.105 Safari/537.36',
    }

    response = request_util.get(url, params, headers=headers)

    ret = re.match("jsonpCallback22015\((.*)\)", response.text)
    data = json.loads(ret.group(1))['result'][0]

    item = {}
    for key, value in sh_stock_config.company_info_key_map.items():
        item[key] = data.get(value, '').strip()

    return item


if __name__ == '__main__':
    print(json.dumps(get_company_info(688627), indent=2, ensure_ascii=False))



# -*- coding: utf-8 -*-
"""
@File    : company.py
@Date    : 2023-07-18
"""
import json

from stock_open_api.api.eastmoney import company_config
from stock_open_api.utils import request_util


def get_company_info(code):
    """
    公司 基本资料 | 发行相关

    http://emweb.securities.eastmoney.com/PC_HSF10/CompanySurvey/Index?type=web&code=sh603801

    :param code: 股票代码
    :type code: str

    - eg:
    - 深圳证券交易所 SZ301398 或者 sz301398
    - 上海证券交易所 SH688627 或者 sh688627

    :return: 基本资料 + 发行相关
    :rtype: dict

    >>> get_company_info('603801')
    {
      "公司名称": "志邦家居股份有限公司",
      "英文名称": "Zbom Home Collection Co.,Ltd",
      "A股代码": "603801",
      "A股简称": "志邦家居",
      "A股扩位简称": null,
      "曾用名": "志邦股份",
      "B股代码": null,
      "B股简称": null,
      "H股代码": null,
      "H股简称": null,
      "证券类别": "上交所主板A股",
      "上市交易所": "上海证券交易所",
      "所属东财行业": "轻工制造-家具-家具制造",
      "所属证监会行业": "鲁昌华,张京跃,王文兵",
      "总经理": "许帮顺",
      "法人代表": "孙志勇",
      "董秘": "孙娟",
      "董事长": "孙志勇",
      "证券事务代表": "臧晶晶",
      "独立董事": "鲁昌华,张京跃,王文兵",
      "联系电话": "0551-67186564",
      "电子信箱": "zbom@zbom.com",
      "传真": "0551-65203999",
      "公司网址": "www.zbom.com",
      "办公地址": "安徽省合肥市庐阳工业区连水路19号",
      "注册地址": "安徽省合肥市庐阳工业区连水路19号",
      "区域": "安徽",
      "邮政编码": "230061",
      "注册资本(元)": 43654.7813,
      "工商登记": "91340100772816763N",
      "雇员人数": 5151,
      "管理人员人数": 16,
      "律师事务所": "安徽天禾律师事务所",
      "会计师事务所": "大华会计师事务所(特殊普通合伙)",
      "公司介绍": "志邦家居股份有限公司创立于1998年,是中国厨柜行业的先行者...",
      "经营范围": "家具制造;家具零配件生产;家具零配件销售...",
      "成立日期": "2005-04-04",
      "上市日期": "2017-06-30",
      "发行市盈率(倍)": 22.92,
      "网上发行日期": "2017-06-20",
      "发行方式": "网上定价发行,网下询价配售,市值申购",
      "每股面值(元)": 1,
      "发行量(股)": 40000000,
      "每股发行价(元)": 23.47,
      "发行费用(元)": 89434000,
      "发行总市值(元)": 938800000,
      "募集资金净额(元)": 849366000,
      "首日开盘价(元)": 33.8,
      "首日收盘价(元)": 33.8,
      "首日换手率": 0.0914,
      "首日最高价(元)": 33.8,
      "网下配售中签率": 0.02743221,
      "定价中签率": 0.03205759
    }

    """
    url = 'http://emweb.securities.eastmoney.com/PC_HSF10/CompanySurvey/PageAjax'

    params = {
        'code': code
    }

    res = request_util.get(url, params)

    company_info = res.json()['jbzl'][0]
    security_info = res.json()['fxxg'][0]

    company_info.update(security_info)

    item = {}
    for row in company_config.company_key_map:
        value = company_info.get(row['key'])
        if isinstance(value, str):
            value = value.strip()

        # 上市日期 成立日期 网上发行日期
        if row['key'] in ['LISTING_DATE', 'FOUND_DATE', 'ONLINE_ISSUE_DATE']:
            value = value.split(' ')[0]

        item[row['title']] = value

    return item


if __name__ == '__main__':
    print(json.dumps(get_company_info('sh603801'), indent=2, ensure_ascii=False))



# -*- coding: utf-8 -*-
"""
@File    : ListItem.py
@Date    : 2023-07-17
"""


class ListItem(object):
    """
    列表对象
    """
    items = None
    total = 0

    def __init__(self):
        self.items = []

    def to_dict(self):
        return {
            'items': self.items,
            'total': self.total,
        }



# -*- coding: utf-8 -*-
"""
@File    : hk_stock.py
@Date    : 2023-07-17

港股相关接口
"""

import json

from stock_open_api.api.eastmoney import hk_stock_config
from stock_open_api.items.list_item import ListItem
from stock_open_api.utils import time_util, request_util


def get_list(page=1, size=20):
    """港股行情列表

    东方财富网 > 行情中心 > 港股市场 > 全部港股
    http://quote.eastmoney.com/center/gridlist.html#hk_stocks

    :param page: 分页
    :type page: int
    :param size: 分页大小
    :type size: int

    :return: 港股行情列表
    :rtype: ListItem

    >>> get_list()
    {
      "total": 4587,
      "items": [
        {
          "代码": "00491",
          "名称": "英皇文化产业",
          "最新价": 0.075,
          "涨跌额": 0.018,
          "涨跌幅": 31.58,
          "今开": 0.06,
          "最高": 0.078,
          "最低": 0.06,
          "昨收": 0.057,
          "成交量(股)": 28240000,
          "成交额": 2008120.0
        }
      ]
    }
    """
    url = 'http://83.push2.eastmoney.com/api/qt/clist/get'

    params = {
        # 'cb': 'jQuery112408884331980698759_1689562953826',
        'pn': page,  # page num
        'pz': size,  # page size
        'po': 1,
        'np': 1,
        'ut': 'bd1d9ddb04089700cf9c27f6f7426281',
        'fltt': 2,
        'invt': 2,
        'wbp2u': '|0|0|0|web',
        'fid': 'f3',
        'fs': 'm:128 t:3,m:128 t:4,m:128 t:1,m:128 t:2',
        'fields': 'f1,f2,f3,f4,f5,f6,f7,f8,f9,f10,f12,f13,f14,f15,f16,f17,f18,f19,f20,f21,f23,f24,f25,f26,f22,f33,f11,f62,f128,f136,f115,f152',
        # '_': 1689562954034
        '_': time_util.get_timespan_13()
    }

    res = request_util.get(url, params)

    data = res.json()

    list_item = ListItem()
    if data['data'] is None:
        return list_item

    list_item.total = data['data']['total']

    items = []
    for row in data['data']['diff']:
        item = {}

        for map_item in hk_stock_config.list_key_map:
            item[map_item['title']] = row.get(map_item['key'])

        items.append(item)

    list_item.items = items
    return list_item


def get_org_profile(code):
    """
    公司资料

    http://emweb.securities.eastmoney.com/PC_HKF10/pages/home/index.html?code=00491&type=web&color=w#/CompanyProfile

    :param code: str eg: 00491

    :return:
    {
      "证券代码": "00491.HK",
      "公司名称": "英皇文化产业集团有限公司",
      "英文名称": "Emperor Culture Group Limited",
      "注册地": "Bermuda 百慕大",
      "注册地址": "Clarendon House, 2 Church Street, Hamilton, Bermuda",
      "公司成立日期": "1992-03-27",
      "所属行业": "媒体及娱乐",
      "董事长": "范敏嫦",
      "公司秘书": "廖雪盈",
      "员工人数": 598,
      "办公地址": "香港湾仔轩尼诗道288号英皇集团中心28楼",
      "公司网址": "www.empculture.com",
      "E-MAIL": "enquiry@emperorgroup.com",
      "年结日": "06-30",
      "联系电话": "+852 2835-6688",
      "核数师": "安永会计师事务所",
      "传真": "+852 2835-8188",
      "公司介绍": "英皇文化产业集团有限公司(491.HK)主要从事娱乐、媒体及文化发展业务,其中包括(i)戏院营运;及(ii)投资电影及各类文化活动。\r\n於2022年6月30日,本集团营运合共24间戏院,包括於中国内地8间英皇电影城及7间英皇UA电影城、香港7间英皇戏院、澳门1间英皇戏院及马来西亚1间Emperor Cinemas。"
    }

    """
    url = 'https://datacenter.eastmoney.com/securities/api/data/v1/get'

    params = {
        'reportName': 'RPT_HKF10_INFO_ORGPROFILE',
        'columns': 'SECUCODE,SECURITY_CODE,ORG_NAME,ORG_EN_ABBR,BELONG_INDUSTRY,FOUND_DATE,CHAIRMAN,SECRETARY,ACCOUNT_FIRM,REG_ADDRESS,ADDRESS,YEAR_SETTLE_DAY,EMP_NUM,ORG_TEL,ORG_FAX,ORG_EMAIL,ORG_WEB,ORG_PROFILE,REG_PLACE',
        'quoteColumns': '',
        'filter': '(SECUCODE="{}.HK")'.format(code),
        'pageNumber': '1',
        'pageSize': '200',
        'sortTypes': '',
        'sortColumns': '',
        'source': 'F10',
        'client': 'PC',
        'v': '05607491999280683',
    }

    res = request_util.get(url, params)

    data = res.json()['result']['data'][0]

    item = {}
    for row in hk_stock_config.org_profile_key_map:
        value = data.get(row['key'])
        if isinstance(value, str):
            value = value.strip()

        item[row['title']] = value

    return item


def get_security_info(code):
    """
    证券资料
    http://emweb.securities.eastmoney.com/PC_HKF10/pages/home/index.html?code=00491&type=web&color=w#/CompanyProfile

    :param code: str  eg: 00491

    :return:
    {
      "证券代码": "00491.HK",
      "证券简称": "英皇文化产业",
      "上市日期": "1992-06-10 00:00:00",
      "证券类型": "非H股",
      "交易所": "香港交易所",
      "板块": "主板",
      "最新交易单位（每手股数）": 20000,
      "ISIN（国际证券识别编码）": "BMG3036H1079",
      "是否沪港通标的": "否",
      "是否深港通标的": "否"
    }
    """
    url = 'https://datacenter.eastmoney.com/securities/api/data/v1/get'

    params = {
        'reportName': 'RPT_HKF10_INFO_SECURITYINFO',
        'columns': 'SECUCODE,SECURITY_CODE,SECURITY_NAME_ABBR,SECURITY_TYPE,LISTING_DATE,ISIN_CODE,BOARD,TRADE_UNIT,TRADE_MARKET,GANGGUTONGBIAODISHEN,GANGGUTONGBIAODIHU',
        'quoteColumns': '',
        'filter': '(SECUCODE="{}.HK")'.format(code),
        'pageNumber': '1',
        'pageSize': '200',
        'sortTypes': '',
        'sortColumns': '',
        'source': 'F10',
        'client': 'PC',
        'v': '05299608968630529',
    }

    res = request_util.get(url, params)

    data = res.json()['result']['data'][0]

    item = {}
    for row in hk_stock_config.security_info_key_map:
        value = data.get(row['key'])
        if isinstance(value, str):
            value = value.strip()

        item[row['title']] = value

    return item


if __name__ == '__main__':
    print(json.dumps(get_list().to_dict(), indent=2, ensure_ascii=False))



# -*- coding: utf-8 -*-
"""
stock_config.py
上海证券交易所
"""

# 接口数据映射
company_info_key_map = {
    '公司代码': 'COMPANY_CODE',
    '上市日-A': 'LISTINGDATEA',
    '代码-A': 'SECURITY_CODE_A',
    '简称-A': 'SECURITY_ABBR_A',
    '代码-B': 'SECURITY_CODE_B',
    '上市日-B': 'LISTINGADATEB',
    '可转债简称': 'CHANGEABLE_BOND_ABBR',
    '可转债代码': ' CHANGEABLE_BOND_CODE',
    '可转债转股简称': 'OTHER_ABBR',
    '可转债转股代码': 'OTHER_CODE',
    '公司简称-中': 'COMPANY_ABBR',
    '公司简称-英': 'ENGLISH_ABBR',
    '公司全称-中': 'FULLNAME',
    '公司全称-英': 'FULL_NAME_IN_ENGLISH',
    '扩位证券简称': 'SEC_NAME_FULL',
    '上市时是否盈利': 'IF_PROFIT',
    '是否具有表决权差异安排': 'IF_VOTE_DIFFERENCE',
    '注册地址': 'COMPANY_ADDRESS',
    '通讯地址': 'OFFICE_ADDRESS',
    '邮编': 'OFFICE_ZIP',
    '法定代表人': 'LEGAL_REPRESENTATIVE',
    '董事会秘书姓名': 'SECURITY_OF_THE_BOARD_OF_DIRE',
    'E-mail': 'E_MAIL_ADDRESS',
    '联系电话': 'PHONE',
    '网址': 'WWW_ADDRESS',
    'CSRC行业': 'SMALL_CLASS_NAME',
    'SSE行业': 'SSE_CODE_DESC',
    '所属省/直辖市': 'AREA_NAME_DESC',
    '状态-A': 'STATE_CODE_A_DESC',
    '状态-B': 'STATE_CODE_B_DESC',
    '是否上证180样本股': 'SECURITY_30_DESC',
    '是否境外上市': 'FOREIGN_LISTING_DESC',
    '境外上市地': 'FOREIGN_LISTING_ADDRESS',
}



# -*- coding: utf-8 -*-
"""
@File    : company_config.py
@Date    : 2023-07-18
"""
# 公司资料
company_key_map = [
    # 基本资料
    {
        "title": "公司名称",
        "key": "ORG_NAME",
    },
    {
        "title": "英文名称",
        "key": "ORG_NAME_EN",
    },
    {
        "title": "A股代码",
        "key": "STR_CODEA",
    },

    {
        "title": "A股简称",
        "key": "STR_NAMEA",
    },

    {
        "title": "A股扩位简称",
        "key": "EXPAND_NAME_ABBR",
    },
    {
        "title": "曾用名",
        "key": "FORMERNAME",
    },

    {
        "title": "B股代码",
        "key": "STR_CODEB",
    },

    {
        "title": "B股简称",
        "key": "STR_NAMEB",
    },

    {
        "title": "H股代码",
        "key": "STR_CODEH",
    },

    {
        "title": "H股简称",
        "key": "STR_NAMEH",
    },

    {
        "title": "证券类别",
        "key": "SECURITY_TYPE",
    },
    {
        "title": "上市交易所",
        "key": "TRADE_MARKET",
    },
    {
        "title": "所属东财行业",
        "key": "EM2016",
    },
    {
        "title": "所属证监会行业",
        "key": "INDEDIRECTORS",
    },
    {
        "title": "总经理",
        "key": "PRESIDENT",
    },
    {
        "title": "法人代表",
        "key": "LEGAL_PERSON",
    },
    {
        "title": "董秘",
        "key": "SECRETARY",
    },
    {
        "title": "董事长",
        "key": "CHAIRMAN",
    },

    {
        "title": "证券事务代表",
        "key": "SECPRESENT",
    },
    {
        "title": "独立董事",
        "key": "INDEDIRECTORS",
    },

    {
        "title": "联系电话",
        "key": "ORG_TEL",
    },
    {
        "title": "电子信箱",
        "key": "ORG_EMAIL",
    },
    {
        "title": "传真",
        "key": "ORG_FAX",
    },
    {

        "title": "公司网址",
        "key": "ORG_WEB",
    },

    {
        "title": "办公地址",
        "key": "ADDRESS",
    },

    {
        "title": "注册地址",
        "key": "REG_ADDRESS",
    },
    {
        "title": "区域",
        "key": "PROVINCE",
    },
    {
        "title": "邮政编码",
        "key": "ADDRESS_POSTCODE",
    },
    {
        "title": "注册资本(元)",
        "key": "REG_CAPITAL",
    },
    {
        "title": "工商登记",
        "key": "REG_NUM",
    },
    {
        "title": "雇员人数",
        "key": "EMP_NUM",
    },
    {
        "title": "管理人员人数",
        "key": "TATOLNUMBER",
    },
    {
        "title": "律师事务所",
        "key": "LAW_FIRM",
    },
    {
        "title": "会计师事务所",
        "key": "ACCOUNTFIRM_NAME",
    },
    {
        "title": "公司介绍",
        "key": "ORG_PROFILE",
    },
    {
        "title": "经营范围",
        "key": "BUSINESS_SCOPE",
    },

    # 发行相关
    {
        "title": "成立日期",
        "key": "FOUND_DATE",
    },
    {
        "title": "上市日期",
        "key": "LISTING_DATE",
    },
    {
        "title": "发行市盈率(倍)",
        "key": "AFTER_ISSUE_PE",
    },
    {
        "title": "网上发行日期",
        "key": "ONLINE_ISSUE_DATE",
    },
    {
        "title": "发行方式",
        "key": "ISSUE_WAY",
    },
    {
        "title": "每股面值(元)",
        "key": "PAR_VALUE",
    },
    {
        "title": "发行量(股)",
        "key": "TOTAL_ISSUE_NUM",
    },
    {
        "title": "每股发行价(元)",
        "key": "ISSUE_PRICE",
    },
    {
        "title": "发行费用(元)",
        "key": "DEC_SUMISSUEFEE",
    },
    {
        "title": "发行总市值(元)",
        "key": "TOTAL_FUNDS",
    },
    {
        "title": "募集资金净额(元)",
        "key": "NET_RAISE_FUNDS",
    },
    {
        "title": "首日开盘价(元)",
        "key": "OPEN_PRICE",
    },
    {
        "title": "首日收盘价(元)",
        "key": "CLOSE_PRICE",
    },
    {
        "title": "首日换手率",
        "key": "TURNOVERRATE",
    },
    {
        "title": "首日最高价(元)",
        "key": "HIGH_PRICE",
    },
    {
        "title": "网下配售中签率",
        "key": "OFFLINE_VAP_RATIO",
    },
    {
        "title": "定价中签率",
        "key": "ONLINE_ISSUE_LWR",
    },

]



# -*- coding: utf-8 -*-
"""
@File    : time_util.py
@Date    : 2023-07-17
"""

import time


def get_timespan_13():
    """
    获取13位时间戳
    :return:
    """
    return int(time.time() * 1000)


if __name__ == '__main__':
    print(get_timespan_13())



# -*- coding: utf-8 -*-
"""
@File    : neeq_stock.py
@Date    : 2023-07-17
新三板相关接口
"""

import json

from parsel import Selector

from stock_open_api.api.eastmoney import hk_stock_config, neeq_stock_config
from stock_open_api.items.list_item import ListItem
from stock_open_api.utils import time_util, request_util


def get_list(page=1, size=20):
    """
    新三板列表
    东方财富网 > 行情中心 > 新三板 > 全部
    http://quote.eastmoney.com/center/gridlist.html#neeq_stocks

    :param page: int
    :param size: int

    :return: ListItem
    {
      "total": 6749
      "items": [
        {
          "代码": "872874",
          "名称": "金税股份",
          "最新价": 7.26,
          "涨跌额": 3.63,
          "涨跌幅": 100.0,
          "成交量": 1,
          "成交额": 726.0,
          "昨收": 3.63,
          "今开": 7.26,
          "最高": 7.26,
          "最低": 7.26,
          "委比": -66.5
        }
      ]
    }
    """
    url = 'http://96.push2.eastmoney.com/api/qt/clist/get'

    params = {
        # 'cb': 'jQuery1124022247549421839086_1689658974323',
        'pn': page,  # page num
        'pz': size,  # page size
        'po': '1',
        'np': '1',
        'ut': 'bd1d9ddb04089700cf9c27f6f7426281',
        'fltt': '2',
        'invt': '2',
        'wbp2u': '|0|0|0|web',
        'fid': 'f3',
        'fs': 'm:0 t:81 s:!2052',
        'fields': 'f1,f2,f3,f4,f5,f6,f7,f8,f9,f10,f12,f13,f14,f15,f16,f17,f18,f20,f21,f23,f24,f25,f26,f22,f33,f11,f62,f128,f136,f115,f152,f111',
        '_': time_util.get_timespan_13()
    }

    res = request_util.get(url, params)

    data = res.json()

    list_item = ListItem()
    if data['data'] is None:
        return list_item

    list_item.total = data['data']['total']

    items = []
    for row in data['data']['diff']:
        item = {}

        for map_item in neeq_stock_config.list_key_map:
            item[map_item['title']] = row.get(map_item['key'])

        items.append(item)

    list_item.items = items
    return list_item


def get_company_info(code):
    """
    新三板 公司资料+证券资料
    eg: http://xinsanban.eastmoney.com/F10/CompanyInfo/Introduction/839499.html

    :param code: str eg: 839499

    :return: dict
        {
          "证券代码": "839499.NQ",
          "挂牌日期": "2016-10-27",
          "转让方式": "集合竞价",
          "总股本(万股)": "2630",
          "推荐挂牌券商": "方正证券",
          "证券简称": "西南检测",
          "首次交易日": "2017-05-19",
          "市场分层": "创新层",
          "流通股本(万股)": "2630",
          "持续督导券商": "财通证券",
          "公司全称": "杭州西南检测技术股份有限公司",
          "成立日期": "2007-02-06",
          "实际控制人": "姚文宏,魏川",
          "法人代表": "魏川",
          "公司电话": "0571-88073326",
          "公司邮箱": "hzxnjc@hzsouthwest.com",
          "会计事务所": "中兴华会计师事务所(特殊普通合伙)",
          "主营业务": "建设工程地基基础检测",
          "行业分类": "工业-商业和专业服务",
          "注册地址": "浙江省杭州市拱墅区独城206号6幢",
          "办公地址": "浙江省杭州市拱墅区独城206号6幢",
          "公司简介": "杭州西南检测技术股份有限公司成立于2007年2月,2016年10月10日公司成功登录新三板,是一家国家级高新技术型企业、浙江省科技型中小企业、浙江省“凤凰行动”计划入围企业,杭州市专利示范企业,拱墅区快速成长科技型企业(旭日计划2.0)。公司拥有一支高层次的管理及员工队伍。公司是浙江地区为数不多的能同时承担环境检测及工程检测的第三方检测机构,发起创立了浙江省大健康检测产业创新联盟,致力于打造前端环境检测、中端工程检测、末端大健康检测的链式检测体系,为客户提供综合性的、全生命周期的检测及咨询服务,帮助客户提升品牌价值。公司秉持“始于检测、止于至善”的服务理念,依托于公司在勘察、设计、科研等方面的专业技术优势,打造检测后服务体系,为客户提供“管家式服务”。公司重视创新,设立有技术研究中心及博士后创新工作室,配备有专职研究人员,开展了有针对性的技术研究与开发,在大吨位及复杂条件下的静载抗压测试技术、基坑与隧道智能化远程监测技术等方面具有核心优势。公司将进一步加大投资力度,开展新兴检测业务的孵化培育,不断拓展市场空间。加强横向联合,优化管理模式,提升企业的综合实力,为所有客户提供优质服务。",
          "注册资本(亿元)": "0.2630",
          "组织形式": "民营企业",
          "员工总数": "494",
          "公司董秘": "祝世昌",
          "公司传真": "0571-88080313",
          "律师事务所": "北京康达(杭州)律师事务所"
        }
    """
    base_url = "http://xinsanban.eastmoney.com/F10/CompanyInfo/Introduction/{code}.html"
    url = base_url.format(code=code)

    response = request_util.get(url)

    sel = Selector(text=response.text)
    security_info = sel.css("#security_info li")
    company_info = sel.css("#company_info li")
    rows = security_info + company_info

    item = {}
    for row in rows:
        key = row.css(".company-page-item-left::text").extract_first("").strip()
        value = row.css(".company-page-item-right::text").extract_first("").strip()
        item[key] = value

    return item


if __name__ == '__main__':
    print(json.dumps(get_list().to_dict(), indent=2, ensure_ascii=False))
    # print(json.dumps(get_company_info('839499'), indent=2, ensure_ascii=False))



# -*- coding: utf-8 -*-
"""
@File    : sz_stock.py
@Date    : 2023-07-18
深圳证券交易所
"""

from stock_open_api.api.eastmoney import company
from stock_open_api.utils import json_util


def get_company_info(code):
    """
    深圳证券交易所 公司 基本资料 | 发行相关
    http://emweb.securities.eastmoney.com/PC_HSF10/CompanySurvey/Index?type=web&code=sh603801

    :param code: str eg: 688627

    :return:
        {
          "公司名称": "志邦家居股份有限公司",
          "英文名称": "Zbom Home Collection Co.,Ltd",
          "A股代码": "603801",
          "A股简称": "志邦家居",
          "A股扩位简称": null,
          "曾用名": "志邦股份",
          "B股代码": null,
          "B股简称": null,
          "H股代码": null,
          "H股简称": null,
          "证券类别": "上交所主板A股",
          "上市交易所": "上海证券交易所",
          "所属东财行业": "轻工制造-家具-家具制造",
          "所属证监会行业": "鲁昌华,张京跃,王文兵",
          "总经理": "许帮顺",
          "法人代表": "孙志勇",
          "董秘": "孙娟",
          "董事长": "孙志勇",
          "证券事务代表": "臧晶晶",
          "独立董事": "鲁昌华,张京跃,王文兵",
          "联系电话": "0551-67186564",
          "电子信箱": "zbom@zbom.com",
          "传真": "0551-65203999",
          "公司网址": "www.zbom.com",
          "办公地址": "安徽省合肥市庐阳工业区连水路19号",
          "注册地址": "安徽省合肥市庐阳工业区连水路19号",
          "区域": "安徽",
          "邮政编码": "230061",
          "注册资本(元)": 43654.7813,
          "工商登记": "91340100772816763N",
          "雇员人数": 5151,
          "管理人员人数": 16,
          "律师事务所": "安徽天禾律师事务所",
          "会计师事务所": "大华会计师事务所(特殊普通合伙)",
          "公司介绍": "志邦家居股份有限公司创立于1998年,是中国厨柜行业的先行者。现在,志邦专注于整家定制家居的研发、设计、生产与销售。从“更懂生活”的品牌理念出发,以整家生活的定制设计和服务为优势,为亿万家庭提供从厨房到全屋的整家解决方案。作为整家定制领域的专业家居品牌,志邦家居为人们提供整体厨房、全屋定制、木门墙板、成品家配为核心的整家一体化设计、制造、交付业务,在全国拥有六大生产基地,引进国外智能化制造设备,整合优质供应链,确保产品从设计、生产、安装到服务的每一个环节都以人为尺度、以生活为核心,为全球家庭创造理想的家居良品。凭借卓越的品质和口碑,志邦家居获得“中国环境标志认证”“FSC国际森林认证”等60余项国内外权威认证,同时成为国内诸多知名地产商的重要战略合作伙伴;志邦家居的产品远销海外,出口至澳洲、北美、东南亚、中东等国家和地区,是丽思卡尔顿、瑰丽酒店等国际五星级酒店优质供应商,在东南亚开设多家品牌专营店,品牌享誉全球。自2009年起,志邦家居与央视等主流媒体达成战略合作,并于2016年强势进驻纽约时代广场。同年签约前世界跳水冠军郭晶晶女士为品牌形象代言人,并先后联手郎平、杜丽等世界冠军和蔡康永、陈小春、罗嘉良、许茹芸、杨烁、孙杨、吴莫愁、王耀庆、钟汉良、张智霖、李晨等众多明星共同为美好生活赋义。2017年6月30日,志邦家居在上交所A股上市,2019年1月,正式签约世界著名音乐人周杰伦先生为品牌全新形象代言人。未来,我们将以专业的整家定制服务,发现和满足人们对生活空间的需求;以前沿的产品设计,引领和启发人们对生活品质的向往;以稳健的成长,为社会的良性发展创造更多真实的价值。志邦家居致力成为中国家居行业的一流企业、全球家居行业的领先企业,为现实现人们对家的美好想象奋力前行。",
          "经营范围": "家具制造;家具零配件生产;家具零配件销售;家具销售;家具安装和维修服务;地板制造;地板销售;门窗制造加工;门窗销售;金属门窗工程施工;楼梯制造;楼梯销售;家居用品制造;家居用品销售;建筑装饰材料销售;木材加工;家用电器研发;家用电器制造;家用电器销售;家用电器零配件销售;家用电器安装服务;家用纺织制成品制造;非电力家用器具制造;非电力家用器具销售;卫生洁具研发;卫生洁具制造;卫生洁具销售;厨具卫具及日用杂品研发;厨具卫具及日用杂品批发;厨具卫具及日用杂品零售;日用品销售;灯具销售;互联网销售(除销售需要许可的商品);五金产品批发;五金产品零售;燃气器具生产;电子产品销售;第一类医疗器械销售;第二类医疗器械销售;普通货物仓储服务(不含危险化学品等需许可审批的项目);装卸搬运;会议及展览服务;供应链管理服务;专业设计服务;工业设计服务;咨询策划服务;住房租赁;非居住房地产租赁;货物进出口。",
          "成立日期": "2005-04-04",
          "上市日期": "2017-06-30",
          "发行市盈率(倍)": 22.92,
          "网上发行日期": "2017-06-20",
          "发行方式": "网上定价发行,网下询价配售,市值申购",
          "每股面值(元)": 1,
          "发行量(股)": 40000000,
          "每股发行价(元)": 23.47,
          "发行费用(元)": 89434000,
          "发行总市值(元)": 938800000,
          "募集资金净额(元)": 849366000,
          "首日开盘价(元)": 33.8,
          "首日收盘价(元)": 33.8,
          "首日换手率": 0.0914,
          "首日最高价(元)": 33.8,
          "网下配售中签率": 0.02743221,
          "定价中签率": 0.03205759
        }

    """
    return company.get_company_info("SZ{}".format(code))


if __name__ == '__main__':
    print(json_util.encode_json(get_company_info('301398')))



# -*- coding: utf-8 -*-
"""
@File    : iterator_util.py
@Date    : 2023-07-19
"""
from stock_open_api.api.eastmoney import us_chinese_stock


def list_iterator(list_function, *args, **kwargs):
    """
    列表迭代器
    :param list_function:
    :return: list[ListItem]
    """
    page = 0

    while True:
        page += 1

        data = list_function(page=page, *args, **kwargs)

        if len(data.items) == 0:
            break

        yield data


if __name__ == '__main__':
    for data in list_iterator(us_chinese_stock.get_list):
        print(data.to_dict())



# -*- coding: utf-8 -*-
"""
@File    : kcb_stock_config.py
@Date    : 2023-07-17
中国概念股相关接口
"""

list_key_map = [
    {
        "title": "代码",
        "key": "f12",
        "name": "Code"
    },
    {
        "title": "名称",
        "key": "f14",
        "name": "Name"
    },
    {
        "title": "最新价",
        "key": "f2",
        "name": "Close"
    },
    {
        "title": "涨跌幅",
        "key": "f3",
        "name": "ChangePercent"
    },
    {
        "title": "涨跌额",
        "key": "f4",
        "name": "Change"
    },
    {
        "title": "成交量(手)",
        "key": "f5",
        "name": "Volume"
    },
    {
        "title": "成交额",
        "key": "f6",
        "name": "Amount"
    },
    {
        "title": "振幅",
        "key": "f7",
        "name": "Amplitude"
    },
    {
        "title": "最高",
        "key": "f15",
        "name": "Hign"
    },
    {
        "title": "最低",
        "key": "f16",
        "name": "Low"
    },
    {
        "title": "今开",
        "key": "f17",
        "name": "Open"
    },
    {
        "title": "昨收",
        "key": "f18",
        "name": "PreviousClose"
    },
    {
        "title": "量比",
        "key": "f10",
        "name": "VolumeRate"
    },
    {
        "title": "换手率",
        "key": "f8",
        "name": "TurnoverRate"
    },
    {
        "title": "市盈率(动态)",
        "key": "f9",
        "name": "PERation"
    },
    {
        "title": "市净率",
        "key": "f23",
        "name": "PB"
    },
    {
        "title": "总市值",
        "key": "f20"
    },
    {
        "title": "流通市值",
        "key": "f21"
    },
    {
        "title": "60日涨跌幅",
        "key": "f24"
    },
    {
        "title": "年初至今涨跌幅",
        "key": "f25"
    },
    {
        "title": "涨速",
        "key": "f22"
    },
    {
        "title": "5分钟涨跌",
        "key": "f11"
    }
]



# -*- coding: utf-8 -*-
"""
@File    : request_util.py
@Date    : 2023-07-18

a requests wrapper
"""

import requests

from stock_open_api.utils import ua_util

default_headers = {
    'User-Agent': ua_util.User_Agent
}


def request(method, url, **kwargs):
    kwargs.setdefault('headers', default_headers)
    return requests.request(method, url, **kwargs)


def get(url, params=None, **kwargs):
    return request("get", url, params=params, **kwargs)


def post(url, data=None, json=None, **kwargs):
    return request("post", url, data=data, json=json, **kwargs)



# -*- coding: utf-8 -*-
"""
@File    : us_chinese_stock_config.py
@Date    : 2023-07-17
中国概念股相关接口
"""

list_key_map = [
    {
        "title": "代码",
        "key": "f12",
        "name": "Code"
    },
    {
        "title": "名称",
        "key": "f14",
        "name": "Name"
    },
    {
        "title": "最新价(美元)",
        "key": "f2",
        "name": "Close"
    },
    {
        "title": "涨跌额",
        "key": "f4",
        "name": "Change"
    },
    {
        "title": "涨跌幅",
        "key": "f3",
        "name": "ChangePercent"
    },
    {
        "title": "开盘价",
        "key": "f17",
        "name": "Open"
    },
    {
        "title": "最高价",
        "key": "f15",
        "name": "Hign"
    },
    {
        "title": "最低价",
        "key": "f16",
        "name": "Low"
    },
    {
        "title": "昨收价",
        "key": "f18",
        "name": "PreviousClose"
    },
    {
        "title": "总市值(美元)",
        "key": "f20",
    },
    {
        "title": "市盈率",
        "key": "f115",
    }
]


# 公司资料
org_profile_key_map = [
    {
        "title": "证券代码",
        "key": "SECUCODE",
    },
    {
        "title": "公司名称",
        "key": "ORG_EN_ABBR",
    },
    {
        "title": "中文名称",
        "key": "ORG_NAME",
    },
    # {
    #     "title": "注册地",
    #     "key": "REG_PLACE",
    # },
    {
        "title": "注册地址",
        "key": "REG_ADDRESS",
    },
    {
        "title": "成立日期",
        "key": "FOUND_DATE",
    },
    {
        "title": "所属行业",
        "key": "BELONG_INDUSTRY",
    },
    {
        "title": "主席",
        "key": "CHAIRMAN",
    },
    {
        "title": "员工人数",
        "key": "EMP_NUM",
    },
    {
        "title": "办公地址",
        "key": "ADDRESS",
    },
    {
        "title": "公司网址",
        "key": "ORG_WEB",
    },
    {
        "title": "E-MAIL",
        "key": "ORG_EMAIL",
    },

    {
        "title": "电话号码",
        "key": "ORG_TEL",
    },
    {
        "title": "传真号码",
        "key": "ORG_FAX",
    },
    {
        "title": "公司介绍",
        "key": "ORG_PROFILE",
    },
]

# 证券资料
security_info_key_map = [
    {
        "title": "证券代码",
        "key": "SECURITY_CODE",
    },
    # {
    #     "title": "证券简称",
    #     "key": "SECURITY_NAME_ABBR",
    # },
    {
        "title": "上市日期",
        "key": "LISTING_DATE",
    },
    {
        "title": "证券类型",
        "key": "SECURITY_TYPE",
    },
    {
        "title": "上市场所",
        "key": "TRADE_MARKET",
    },
    # {
    #     "title": "板块",
    #     "key": "BOARD",
    # },
    # {
    #     "title": "最新交易单位（每手股数）",
    #     "key": "TRADE_UNIT",
    # },
    {
        "title": "ISIN",
        "key": "ISIN_CODE",
    },
    {
        "title": "每股面值",
        "key": "PAR_VALUE",
    },
    {
        "title": "ADS折算比",
        "key": "CONVERT_RATIO",
    },
    {
        "title": "年结日",
        "key": "YEAR_SETTLE_DAY",
    },
]


# -*- coding: utf-8 -*-

# @Date    : 2019-06-26
# @Author  : Peng Shiyu
from __future__ import print_function, unicode_literals, absolute_import, division

import glob
import io
import os

from setuptools import setup, find_packages

"""
## 本地测试
安装测试
python setup.py develop 
python setup.py develop --uninstall

卸载
pip uninstall spideradmin -y


## 打包上传
先升级打包工具
pip install --upgrade setuptools wheel twine

打包
python setup.py sdist bdist_wheel

检查
twine check dist/*

上传pypi
twine upload dist/*

命令整合
rm -rf dist build *.egg-info \
&& python setup.py sdist bdist_wheel  \
&& twine check dist/* \
&& twine upload dist/*


## 下载测试
安装测试
pip3 install -U stock-open-api -i https://pypi.org/simple

打包的用的setup必须引入

参考：
https://packaging.python.org/guides/making-a-pypi-friendly-readme/

"""

# 版本号
version_file = glob.glob("*/version.py")[0]

with io.open(version_file, 'rb') as f:
    version_var = {}
    exec(f.read(), version_var)
    VERSION = version_var['VERSION']

with io.open("README.md", 'r', encoding='utf-8') as f:
    long_description = f.read()

with io.open("requirements/production.txt", 'r') as f:
    install_requires = f.read().split(os.sep)

setup(
    name='stock-open-api',
    version=VERSION,
    description="a api collection for stock",

    keywords='stock,api',
    author='Peng Shiyu',
    author_email='pengshiyuyx@gmail.com',
    license='MIT',
    url="https://github.com/mouday/stock-open-api",

    long_description=long_description,
    long_description_content_type='text/markdown',
    platforms=['any'],
    # Get strings from http://pypi.python.org/pypi?%3Aaction=list_classifiers
    classifiers=[
        'Development Status :: 5 - Production/Stable',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
        'Programming Language :: Python :: 3.10',
        'Programming Language :: Python :: 3.11',
        'Programming Language :: Python :: 3.12',
        # 'Programming Language :: Python :: 3.13',
        # 'Programming Language :: Python :: 3.14',
        # 'Programming Language :: Python :: 3.15',
        # 'Programming Language :: Python :: 999.99',
        "Topic :: Internet :: WWW/HTTP :: Dynamic Content",
        "Topic :: Internet :: WWW/HTTP :: WSGI :: Application",
        "Topic :: Software Development :: Libraries :: Application Frameworks",
        "Topic :: Software Development :: Libraries :: Python Modules",
    ],

    packages=find_packages(),
    include_package_data=True,
    zip_safe=True,
    install_requires=install_requires
)



# -*- coding: utf-8 -*-
"""
@File    : hk_stocks_config.py
@Date    : 2023-07-17
"""

list_key_map = [
    {
        "title": "代码",
        "key": "f12",
        "name": "Code"
    },
    {
        "title": "名称",
        "key": "f14",
        "name": "Name"
    },

    {
        "title": "最新价",
        "key": "f2",
        "name": "Close"
    },
    {
        "title": "涨跌额",
        "key": "f4",
        "name": "Change"
    },
    {
        "title": "涨跌幅",
        "key": "f3",
        "name": "ChangePercent"
    },
    {
        "title": "成交量",
        "key": "f5",
        "name": "Volume"
    },
    {
        "title": "成交额",
        "key": "f6",
        "name": "Amount"
    },
    {
        "title": "昨收",
        "key": "f18",
        "name": "PreviousClose"
    },
    {
        "title": "今开",
        "key": "f17",
        "name": "Open"
    },
    {
        "title": "最高",
        "key": "f15",
        "name": "Hign"
    },
    {
        "title": "最低",
        "key": "f16",
        "name": "Low"
    },
    {
        "title": "委比",
        "key": "f33",
        "name": "weibi"
    },
]



# -*- coding: utf-8 -*-
"""
@File    : ua_util.py
@Date    : 2023-07-17
"""

User_Agent = 'Mozilla/5.0 (Macintosh; Intel Mac OS X 10_15_7) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/114.0.0.0 Safari/537.36'


# -*- coding: utf-8 -*-
"""
@File    : us_chinese_stock.py
@Date    : 2023-07-17
中国概念股相关接口
"""
import json

from stock_open_api.api.eastmoney import us_chinese_stock_config
from stock_open_api.items.list_item import ListItem
from stock_open_api.log import logger
from stock_open_api.utils import time_util, request_util


def get_list(page=1, size=20):
    """
    中国概念股 列表
    东方财富网 > 行情中心 > 美股市场 > 中国概念股
    http://quote.eastmoney.com/center/gridlist.html#us_chinese

    :param page: int
    :param size: int

    :return: ListItem
    {
      "total": 384,
      "items": [
        {
          "代码": "PWM",
          "名称": "盛德财富",
          "最新价(美元)": 17.0,
          "涨跌额": 5.33,
          "涨跌幅": 45.67,
          "开盘价": 10.5,
          "最高价": 19.5,
          "最低价": 10.5,
          "昨收价": 11.67,
          "总市值(美元)": 153000000,
          "市盈率": 112.95
        }
      ]
    }
    """
    url = 'http://45.push2.eastmoney.com/api/qt/clist/get'

    params = {
        # 'cb': 'jQuery1124004782104701641621_1689648873162',
        'pn': page,
        'pz': size,
        'po': '1',
        'np': '1',
        'ut': 'bd1d9ddb04089700cf9c27f6f7426281',
        'fltt': '2',
        'invt': '2',
        'wbp2u': '|0|0|0|web',
        'fid': 'f3',
        'fs': 'b:MK0201',
        'fields': 'f1,f2,f3,f4,f5,f6,f7,f8,f9,f10,f12,f13,f14,f15,f16,f17,f18,f20,f21,f23,f24,f25,f26,f22,f33,f11,f62,f128,f136,f115,f152',
        # '_': '1689648873172',
        '_': time_util.get_timespan_13()
    }

    res = request_util.get(url, params)

    data = res.json()

    list_item = ListItem()
    if data['data'] is None:
        return list_item

    list_item.total = data['data']['total']

    items = []
    for row in data['data']['diff']:
        item = {}

        for map_item in us_chinese_stock_config.list_key_map:
            item[map_item['title']] = row.get(map_item['key'])

        items.append(item)

    list_item.items = items
    return list_item


def get_org_profile(code):
    """
    中国概念股 公司资料
    http://emweb.eastmoney.com/PC_USF10/pages/index.html?code=PWM&type=web&color=w#/gsgk/gszl

    :param code: str eg: PWM

    :return:
    {
      "证券代码": "PWM.O",
      "公司名称": "Prestige Wealth Inc.",
      "中文名称": "盛德财富有限公司",
      "注册地址": null,
      "成立日期": "2018-10-25",
      "所属行业": "投资银行业与经纪业",
      "主席": "Hongtao Shi(师鸿涛)",
      "员工人数": 6,
      "办公地址": "香港中环皇后大道中2号长江集团中心51楼5102室",
      "公司网址": "www.prestigewealthinc.com",
      "E-MAIL": null,
      "电话号码": "+852 2122-8560",
      "传真号码": "+852 2122 8589",
      "公司介绍": "盛德财富有限公司是一家在开曼群岛注册成立的境外控股母公司,主要由其境内实体子公司Prestige Financial Holdings Group Limited运营。盛德财富有限公司(“PWI”,或“公司”)是一家于2018年10月25日根据开曼群岛法律成立的有限公司。该公司通过其子公司向高净值和超高净值个人和企业提供私人财富管理服务和资产管理。"
    }
    """
    detail_url = 'http://emweb.eastmoney.com/PC_USF10/pages/index.html?code={}&type=web&color=w#/gsgk/gszl'.format(code)
    logger.debug(detail_url)

    url = 'https://datacenter.eastmoney.com/securities/api/data/v1/get'

    params = {
        'reportName': 'RPT_USF10_INFO_ORGPROFILE',
        'columns': 'SECUCODE,SECURITY_CODE,ORG_CODE,SECURITY_INNER_CODE,ORG_NAME,ORG_EN_ABBR,BELONG_INDUSTRY,FOUND_DATE,CHAIRMAN,REG_PLACE,ADDRESS,EMP_NUM,ORG_TEL,ORG_FAX,ORG_EMAIL,ORG_WEB,ORG_PROFILE',
        'quoteColumns': '',
        'filter': '(SECURITY_CODE="{}")'.format(code),
        'pageNumber': '1',
        'pageSize': '200',
        'sortTypes': '',
        'sortColumns': '',
        'source': 'SECURITIES',
        'client': 'PC',
        'v': '016960969044233054',
    }

    res = request_util.get(url, params)

    data = res.json()['result']['data'][0]

    item = {}
    for row in us_chinese_stock_config.org_profile_key_map:
        value = data.get(row['key'])
        if isinstance(value, str):
            value = value.strip()

        item[row['title']] = value

    return item


def get_security_info(code):
    """
    中国概念股 证券资料
    http://emweb.eastmoney.com/PC_USF10/pages/index.html?code=PWM&type=web&color=w#/gsgk/zqzl

    :param code: str eg: PWM.O

    :return:
    {
      "证券代码": "PWM",
      "上市日期": "2023-07-06",
      "证券类型": "美股",
      "上市场所": "NASDAQ",
      "ISIN": "KYG7244A1013",
      "每股面值": "0.000625 USD",
      "ADS折算比": null,
      "年结日": "09-30"
    }
    """
    url = 'https://datacenter.eastmoney.com/securities/api/data/v1/get'

    params = {
        'reportName': 'RPT_USF10_INFO_SECURITYINFO',
        'columns': 'SECUCODE,SECURITY_CODE,ORG_CODE,SECURITY_INNER_CODE,SECURITY_TYPE,LISTING_DATE,ISIN_CODE,TRADE_MARKET,YEAR_SETTLE_DAY,PAR_VALUE,CONVERT_RATIO,ISSUE_PRICE,ISSUE_NUM',
        'quoteColumns': '',
        'filter': '(SECUCODE="{}")'.format(code),
        'pageNumber': '1',
        'pageSize': '200',
        'sortTypes': '',
        'sortColumns': '',
        'source': 'SECURITIES',
        'client': 'PC',
        'v': '034528884905654467',
    }

    res = request_util.get(url, params)

    data = res.json()['result']['data'][0]

    item = {}
    for row in us_chinese_stock_config.security_info_key_map:
        value = data.get(row['key'])
        if isinstance(value, str):
            value = value.strip()

        # 上市日期
        if row['key'] == 'LISTING_DATE':
            value = value.split(' ')[0]

        item[row['title']] = value

    return item


if __name__ == '__main__':
    # print(json.dumps(get_list().to_dict(), indent=2, ensure_ascii=False))
    # print(json.dumps(get_org_profile('STG'), indent=2, ensure_ascii=False))
    print(json.dumps(get_security_info('STG.N'), indent=2, ensure_ascii=False))
